@@ -29,11 +29,11 @@ using namespace std;
 FavoriteHubs::FavoriteHubs():
 	BookEntry(Entry::FAVORITE_HUBS, _("Favorite Hubs"), "favoritehubs.glade")
 {
-	// Configure the dialogs
-	gtk_dialog_set_alternative_button_order(GTK_DIALOG(getWidget("deleteFavoriteDialog")), GTK_RESPONSE_OK, GTK_RESPONSE_CANCEL, -1);
+	// Configure the dialog
 	gtk_dialog_set_alternative_button_order(GTK_DIALOG(getWidget("favoriteHubsDialog")), GTK_RESPONSE_OK, GTK_RESPONSE_CANCEL, -1);
 
 	// Fill the charset drop-down list in edit fav hub dialog.
+	gtk_combo_box_append_text(GTK_COMBO_BOX(getWidget("comboboxCharset")), WulforUtil::ENCODING_GLOBAL_HUB_DEFAULT.c_str());
 	vector<string> &charsets = WulforUtil::getCharsets();
 	for (vector<string>::const_iterator it = charsets.begin(); it != charsets.end(); ++it)
 		gtk_combo_box_append_text(GTK_COMBO_BOX(getWidget("comboboxCharset")), it->c_str());
@@ -82,8 +82,6 @@ FavoriteHubs::FavoriteHubs():
 FavoriteHubs::~FavoriteHubs()
 {
 	FavoriteManager::getInstance()->removeListener(this);
-	gtk_widget_destroy(getWidget("deleteFavoriteDialog"));
-	gtk_widget_destroy(getWidget("errorDialog"));
 }
 
 void FavoriteHubs::show()
@@ -102,6 +100,8 @@ void FavoriteHubs::addEntry_gui(StringMap params)
 
 void FavoriteHubs::editEntry_gui(StringMap &params, GtkTreeIter *iter)
 {
+	string encoding = params["Encoding"].empty() ? WulforUtil::ENCODING_GLOBAL_HUB_DEFAULT : params["Encoding"];
+
 	gtk_list_store_set(favoriteStore, iter,
 		favoriteView.col("Auto Connect"), Util::toInt(params["Auto Connect"]),
 		favoriteView.col("Name"), params["Name"].c_str(),
@@ -111,7 +111,7 @@ void FavoriteHubs::editEntry_gui(StringMap &params, GtkTreeIter *iter)
 		favoriteView.col("Hidden Password"), params["Hidden Password"].c_str(),
 		favoriteView.col("Address"), params["Address"].c_str(),
 		favoriteView.col("User Description"), params["User Description"].c_str(),
-		favoriteView.col("Encoding"), params["Encoding"].c_str(),
+		favoriteView.col("Encoding"), encoding.c_str(),
 		-1);
 }
 
@@ -134,9 +134,10 @@ void FavoriteHubs::removeEntry_gui(string address)
 
 void FavoriteHubs::showErrorDialog_gui(const string &description)
 {
-	gtk_label_set_text(GTK_LABEL(getWidget("errorLabel")), description.c_str());
-	gtk_dialog_run(GTK_DIALOG(getWidget("errorDialog")));
-	gtk_widget_hide(getWidget("errorDialog"));
+	GtkWidget* dialog = gtk_message_dialog_new(GTK_WINDOW(getWidget("favoriteHubsDialog")),
+		GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, "%s", description.c_str());
+	gtk_dialog_run(GTK_DIALOG(dialog));
+	gtk_widget_destroy(dialog);
 }
 
 void FavoriteHubs::popupMenu_gui()
@@ -240,14 +241,14 @@ void FavoriteHubs::onAddEntry_gui(GtkWidget *widget, gpointer data)
 	gtk_entry_set_text(GTK_ENTRY(fh->getWidget("entryNick")), "");
 	gtk_entry_set_text(GTK_ENTRY(fh->getWidget("entryPassword")), "");
 	gtk_entry_set_text(GTK_ENTRY(fh->getWidget("entryUDescription")), "");
-	gtk_entry_set_text(GTK_ENTRY(fh->getWidget("comboboxentryCharset")), WGETS("default-charset").c_str());
+	gtk_entry_set_text(GTK_ENTRY(fh->getWidget("comboboxentryCharset")), WulforUtil::ENCODING_GLOBAL_HUB_DEFAULT.c_str());
 
 	int response = gtk_dialog_run(GTK_DIALOG(fh->getWidget("favoriteHubsDialog")));
-	gtk_widget_hide(fh->getWidget("favoriteHubsDialog"));
 
-	if (response == GTK_RESPONSE_OK)
+	while (response == GTK_RESPONSE_OK)
 	{
 		StringMap params;
+
 		params["Name"] = gtk_entry_get_text(GTK_ENTRY(fh->getWidget("entryName")));
 		params["Address"] = gtk_entry_get_text(GTK_ENTRY(fh->getWidget("entryAddress")));
 		params["Description"] = gtk_entry_get_text(GTK_ENTRY(fh->getWidget("entryDescription")));
@@ -262,14 +263,18 @@ void FavoriteHubs::onAddEntry_gui(GtkWidget *widget, gpointer data)
 		if (params["Name"].empty() || params["Address"].empty())
 		{
 			fh->showErrorDialog_gui(_("The name and address fields are required"));
+			response = gtk_dialog_run(GTK_DIALOG(fh->getWidget("favoriteHubsDialog")));
 		}
 		else
 		{
 			typedef Func1<FavoriteHubs, StringMap> F1;
 			F1 *func = new F1(fh, &FavoriteHubs::addEntry_client, params);
 			WulforManager::get()->dispatchClientFunc(func);
+			response = GTK_RESPONSE_CANCEL;
 		}
 	}
+
+	gtk_widget_hide(fh->getWidget("favoriteHubsDialog"));
 }
 
 void FavoriteHubs::onEditEntry_gui(GtkWidget *widget, gpointer data)
@@ -298,9 +303,8 @@ void FavoriteHubs::onEditEntry_gui(GtkWidget *widget, gpointer data)
 	gtk_entry_set_text(GTK_ENTRY(fh->getWidget("comboboxentryCharset")), params["Encoding"].c_str());
 
 	int response = gtk_dialog_run(GTK_DIALOG(fh->getWidget("favoriteHubsDialog")));
-	gtk_widget_hide(fh->getWidget("favoriteHubsDialog"));
 
-	if (response == GTK_RESPONSE_OK)
+	while (response == GTK_RESPONSE_OK)
 	{
 		params.clear();
 		params["Name"] = gtk_entry_get_text(GTK_ENTRY(fh->getWidget("entryName")));
@@ -317,6 +321,7 @@ void FavoriteHubs::onEditEntry_gui(GtkWidget *widget, gpointer data)
 		if (params["Name"].empty() || params["Address"].empty())
 		{
 			fh->showErrorDialog_gui(_("The name and address fields are required"));
+			response = gtk_dialog_run(GTK_DIALOG(fh->getWidget("favoriteHubsDialog")));
 		}
 		else
 		{
@@ -326,8 +331,11 @@ void FavoriteHubs::onEditEntry_gui(GtkWidget *widget, gpointer data)
 			typedef Func2<FavoriteHubs, string, StringMap> F2;
 			F2 *func = new F2(fh, &FavoriteHubs::editEntry_client, address, params);
 			WulforManager::get()->dispatchClientFunc(func);
+			response = GTK_RESPONSE_CANCEL;
 		}
 	}
+
+	gtk_widget_hide(fh->getWidget("favoriteHubsDialog"));
 }
 
 void FavoriteHubs::onRemoveEntry_gui(GtkWidget *widget, gpointer data)
@@ -339,9 +347,17 @@ void FavoriteHubs::onRemoveEntry_gui(GtkWidget *widget, gpointer data)
 	{
 		if (BOOLSETTING(CONFIRM_HUB_REMOVAL))
 		{
-			gint response = gtk_dialog_run(GTK_DIALOG(fh->getWidget("deleteFavoriteDialog")));
-			gtk_widget_hide(fh->getWidget("deleteFavoriteDialog"));
-			if (response != GTK_RESPONSE_OK)
+			string name = fh->favoriteView.getString(&iter, "Name").c_str();
+			GtkWindow* parent = GTK_WINDOW(WulforManager::get()->getMainWindow()->getContainer());
+			GtkWidget* dialog = gtk_message_dialog_new(parent,
+				GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
+				_("Are you sure you want to delete favorite hub \"%s\"?"), name.c_str());
+			gtk_dialog_add_buttons(GTK_DIALOG(dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_REMOVE, GTK_RESPONSE_YES, NULL);
+			gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog), GTK_RESPONSE_YES, GTK_RESPONSE_CANCEL, -1);
+			gint response = gtk_dialog_run(GTK_DIALOG(dialog));
+			gtk_widget_destroy(dialog);
+
+			if (response != GTK_RESPONSE_YES)
 				return;
 		}
 
@@ -415,7 +431,7 @@ void FavoriteHubs::getFavHubParams_client(const FavoriteHubEntry *entry, StringM
 	params["Hidden Password"] = entry->getPassword();
 	params["Address"] = entry->getServer();
 	params["User Description"] = entry->getUserDescription();
-	params["Encoding"] = entry->getEncoding().empty() ? WGETS("default-charset") : entry->getEncoding();
+	params["Encoding"] = entry->getEncoding();
 }
 
 void FavoriteHubs::addEntry_client(StringMap params)
