@@ -51,12 +51,11 @@ Hub::Hub(const string &address, const string &encoding):
 	// Initialize nick treeview
 	nickView.setView(GTK_TREE_VIEW(getWidget("nickView")), true, "hub");
 	nickView.insertColumn("Nick", G_TYPE_STRING, TreeView::PIXBUF_STRING, 100, "Icon");
-	nickView.insertColumn("Shared", G_TYPE_STRING, TreeView::STRING, 75);
+	nickView.insertColumn("Shared", G_TYPE_INT64, TreeView::BYTE, 75);
 	nickView.insertColumn("Description", G_TYPE_STRING, TreeView::STRING, 85);
 	nickView.insertColumn("Tag", G_TYPE_STRING, TreeView::STRING, 100);
 	nickView.insertColumn("Connection", G_TYPE_STRING, TreeView::STRING, 85);
 	nickView.insertColumn("eMail", G_TYPE_STRING, TreeView::STRING, 90);
-	nickView.insertHiddenColumn("Shared Bytes", G_TYPE_INT64);
 	nickView.insertHiddenColumn("Icon", GDK_TYPE_PIXBUF);
 	nickView.insertHiddenColumn("Nick Order", G_TYPE_STRING);
 	nickView.insertHiddenColumn("CID", G_TYPE_STRING);
@@ -67,7 +66,6 @@ Hub::Hub(const string &address, const string &encoding):
 	nickSelection = gtk_tree_view_get_selection(nickView.get());
 	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(nickView.get()), GTK_SELECTION_MULTIPLE);
 	nickView.setSortColumn_gui("Nick", "Nick Order");
-	nickView.setSortColumn_gui("Shared", "Shared Bytes");
 	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(nickStore), nickView.col("Nick Order"), GTK_SORT_ASCENDING);
 	gtk_tree_view_column_set_sort_indicator(gtk_tree_view_get_column(nickView.get(), nickView.col("Nick")), TRUE);
 	gtk_tree_view_set_fixed_height_mode(nickView.get(), TRUE);
@@ -216,20 +214,19 @@ bool Hub::findUser_gui(const string &nick, GtkTreeIter *iter)
 void Hub::updateUser_gui(ParamMap params)
 {
 	GtkTreeIter iter;
-	int64_t shared = Util::toInt64(params["Shared Bytes"]);
+	int64_t shared = Util::toInt64(params["Shared"]);
 
 	if (findUser_gui(params["Nick"], &iter))
 	{
-		totalShared += shared - nickView.getValue<int64_t>(&iter, "Shared Bytes");
+		totalShared += shared - nickView.getValue<int64_t>(&iter, "Shared");
 
 		gtk_list_store_set(nickStore, &iter,
 			nickView.col("Nick"), params["Nick"].c_str(),
-			nickView.col("Shared"), params["Shared"].c_str(),
+			nickView.col("Shared"), shared,
 			nickView.col("Description"), params["Description"].c_str(),
 			nickView.col("Tag"), params["Tag"].c_str(),
  			nickView.col("Connection"), params["Connection"].c_str(),
 			nickView.col("eMail"), params["eMail"].c_str(),
-			nickView.col("Shared Bytes"), shared,
  			nickView.col("Icon"), userIcons[params["Icon"]],
 			nickView.col("Nick Order"), params["Nick Order"].c_str(),
 			-1);
@@ -252,12 +249,11 @@ void Hub::updateUser_gui(ParamMap params)
 
 		gtk_list_store_insert_with_values(nickStore, &iter, userMap.size(),
 			nickView.col("Nick"), params["Nick"].c_str(),
-			nickView.col("Shared"), params["Shared"].c_str(),
+			nickView.col("Shared"), shared,
 			nickView.col("Description"), params["Description"].c_str(),
 			nickView.col("Tag"), params["Tag"].c_str(),
  			nickView.col("Connection"), params["Connection"].c_str(),
 			nickView.col("eMail"), params["eMail"].c_str(),
-			nickView.col("Shared Bytes"), shared,
  			nickView.col("Icon"), userIcons[params["Icon"]],
 			nickView.col("Nick Order"), params["Nick Order"].c_str(),
 			nickView.col("CID"), params["CID"].c_str(),
@@ -276,7 +272,7 @@ void Hub::removeUser_gui(string nick)
 
 	if (findUser_gui(nick, &iter))
 	{
-		totalShared -= nickView.getValue<int64_t>(&iter, "Shared Bytes");
+		totalShared -= nickView.getValue<int64_t>(&iter, "Shared");
 		gtk_list_store_remove(nickStore, &iter);
 		userMap.erase(nick);
 		userIters.erase(nick);
@@ -915,11 +911,12 @@ void Hub::onSendMessage_gui(GtkEntry *entry, gpointer data)
 			if (BOOLSETTING(JOIN_OPEN_NEW_WINDOW))
 			{
 				// Assumption: new hub is same encoding as current hub.
-				WulforManager::get()->getMainWindow()->showHub_gui(param, hub->client->getEncoding());
+				WulforManager::get()->getMainWindow()->showHub_gui(param, hub->encoding);
 			}
 			else
 			{
-				func = new F1(hub, &Hub::redirect_client, param);
+				typedef Func2<Hub, string, bool> F2;
+				F2 *func = new F2(hub, &Hub::redirect_client, param, TRUE);
 				WulforManager::get()->dispatchClientFunc(func);
 			}
 		}
@@ -1177,12 +1174,13 @@ void Hub::connectClient_client(string address, string encoding)
 
 	if (address.substr(0, 6) == "adc://" || address.substr(0, 7) == "adcs://")
 		encoding = "UTF-8";
-	else if (encoding.empty())
+	else if (encoding.empty() || encoding == WulforUtil::ENCODING_GLOBAL_HUB_DEFAULT)
 		encoding = WGETS("default-charset");
 
-	if (encoding == _("System default"))
+	if (encoding == WulforUtil::ENCODING_SYSTEM_DEFAULT)
 		encoding = Text::getSystemCharset();
 
+	// Only pick "UTF-8" part of "UTF-8 (Unicode)".
 	string::size_type i = encoding.find(' ', 0);
 	if (i != string::npos)
 		encoding = encoding.substr(0, i);
@@ -1230,13 +1228,24 @@ void Hub::getFileList_client(string cid, bool match)
 			User::Ptr user = ClientManager::getInstance()->findUser(CID(cid));
 			if (user)
 			{
-				if (match)
+				if (user == ClientManager::getInstance()->getMe())
+				{
+					// Don't download file list, open locally instead
+					WulforManager::get()->getMainWindow()->openOwnList_client(TRUE);
+				}
+				else if (match)
+				{
 					QueueManager::getInstance()->addList(user, QueueItem::FLAG_MATCH_QUEUE);
+				}
 				else
+				{
 					QueueManager::getInstance()->addList(user, QueueItem::FLAG_CLIENT_VIEW);
+				}
 			}
 			else
+			{
 				message = _("User not found");
+			}
 		}
 		catch (const Exception &e)
 		{
@@ -1282,7 +1291,7 @@ void Hub::removeUserFromQueue_client(std::string cid)
 	}
 }
 
-void Hub::redirect_client(string address)
+void Hub::redirect_client(string address, bool follow)
 {
 	if (!address.empty())
 	{
@@ -1295,10 +1304,9 @@ void Hub::redirect_client(string address)
 			return;
 		}
 
-		if (BOOLSETTING(AUTO_FOLLOW))
+		if (follow)
 		{
 			// the client is dead, long live the client!
-			string encoding = client->getEncoding();
 			disconnect_client();
 
 			Func0<Hub> *func = new Func0<Hub>(this, &Hub::clearNickList_gui);
@@ -1341,6 +1349,7 @@ void Hub::addAsFavorite_client()
 		aEntry.setDescription(client->getHubDescription());
 		aEntry.setConnect(FALSE);
 		aEntry.setNick(client->getMyNick());
+		aEntry.setEncoding(encoding);
 		FavoriteManager::getInstance()->addFavorite(aEntry);
 		func = new F1(this, &Hub::addStatusMessage_gui, _("Favorite hub added"));
 		WulforManager::get()->dispatchGuiFunc(func);
@@ -1395,12 +1404,11 @@ void Hub::getParams_client(ParamMap &params, Identity &id)
 	}
 
 	params["Nick"] = id.getNick();
-	params["Shared"] = Util::formatBytes(id.getBytesShared());
+	params["Shared"] = Util::toString(id.getBytesShared());
 	params["Description"] = id.getDescription();
 	params["Tag"] = id.getTag();
 	params["Connection"] = id.getConnection();
 	params["eMail"] = id.getEmail();
-	params["Shared Bytes"] = Util::toString(id.getBytesShared());
 	params["CID"] = id.getUser()->getCID().toBase32();
 }
 
@@ -1470,7 +1478,8 @@ void Hub::on(ClientListener::UserRemoved, Client *, const OnlineUser &user) thro
 void Hub::on(ClientListener::Redirect, Client *, const string &address) throw()
 {
 	// redirect_client() crashes unless I put it into the dispatcher (why?)
-	Func1<Hub, string> *func = new Func1<Hub, string>(this, &Hub::redirect_client, address);
+	typedef Func2<Hub, string, bool> F2;
+	F2 *func = new F2(this, &Hub::redirect_client, address, BOOLSETTING(AUTO_FOLLOW));
 	WulforManager::get()->dispatchClientFunc(func);
 }
 
