@@ -28,7 +28,6 @@
 #include <client/ShareManager.h>
 #include <client/Text.h>
 #include "downloadqueue.hh"
-#include "eggtrayicon.h"
 #include "favoritehubs.hh"
 #include "finishedtransfers.hh"
 #include "func.hh"
@@ -106,7 +105,7 @@ MainWindow::MainWindow():
 	gtk_about_dialog_set_email_hook((GtkAboutDialogActivateLinkFunc)onAboutDialogActivateLink_gui, (gpointer)this, NULL);
 	gtk_about_dialog_set_url_hook((GtkAboutDialogActivateLinkFunc)onAboutDialogActivateLink_gui, (gpointer)this, NULL);
 	// This has to be set in code in order to activate the link
-	gtk_about_dialog_set_website(GTK_ABOUT_DIALOG(getWidget("aboutDialog")), "http://linuxdcpp.berlios.de");
+	gtk_about_dialog_set_website(GTK_ABOUT_DIALOG(getWidget("aboutDialog")), "https://launchpad.net/linuxdcpp");
 
 	// Set all windows to the default icon
 	file = path + "linuxdcpp-icon.png";
@@ -126,16 +125,14 @@ MainWindow::MainWindow():
 	else
 		transferView.insertColumn("Status", G_TYPE_STRING, TreeView::STRING, 250);
 	transferView.insertColumn("Time Left", G_TYPE_STRING, TreeView::STRING, 85);
-	transferView.insertColumn("Speed", G_TYPE_STRING, TreeView::STRING, 125);
+	transferView.insertColumn("Speed", G_TYPE_INT64, TreeView::SPEED, 125);
 	transferView.insertColumn("Filename", G_TYPE_STRING, TreeView::STRING, 200);
-	transferView.insertColumn("Size", G_TYPE_STRING, TreeView::STRING, 125);
+	transferView.insertColumn("Size", G_TYPE_INT64, TreeView::BYTE, 125);
 	transferView.insertColumn("Path", G_TYPE_STRING, TreeView::STRING, 200);
 	transferView.insertColumn("IP", G_TYPE_STRING, TreeView::STRING, 175);
 	transferView.insertHiddenColumn("Icon", GDK_TYPE_PIXBUF);
 	transferView.insertHiddenColumn("Progress", G_TYPE_INT);
 	transferView.insertHiddenColumn("Sort Order", G_TYPE_STRING);
-	transferView.insertHiddenColumn("Speed Order", G_TYPE_INT64);
-	transferView.insertHiddenColumn("Size Order", G_TYPE_INT64);
 	transferView.insertHiddenColumn("CID", G_TYPE_STRING);
 	transferView.finalize();
 	transferStore = gtk_list_store_newv(transferView.getColCount(), transferView.getGTypes());
@@ -144,8 +141,6 @@ MainWindow::MainWindow():
 	transferSelection = gtk_tree_view_get_selection(transferView.get());
 	gtk_tree_selection_set_mode(transferSelection, GTK_SELECTION_MULTIPLE);
 	transferView.setSortColumn_gui("User", "Sort Order");
-	transferView.setSortColumn_gui("Speed", "Speed Order");
-	transferView.setSortColumn_gui("Size", "Size Order");
 	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(transferStore), transferView.col("Sort Order"), GTK_SORT_ASCENDING);
 	gtk_tree_view_column_set_sort_indicator(gtk_tree_view_get_column(transferView.get(), transferView.col("User")), TRUE);
 	gtk_tree_view_set_fixed_height_mode(transferView.get(), TRUE);
@@ -224,7 +219,7 @@ MainWindow::MainWindow():
 	gtk_widget_destroy(dummy);
 	emptyStatusWidth = req.width;
 
-	setMainStatus_gui(_("Welcome to LinuxDC++"));
+	setMainStatus_gui(_("Welcome to ") + string(g_get_application_name()));
 
 	// Putting this after all the resizing and moving makes the window appear
 	// in the correct position instantly, looking slightly more cool
@@ -233,7 +228,7 @@ MainWindow::MainWindow():
 	setTabPosition_gui(WGETI("tab-position"));
 	setToolbarStyle_gui(WGETI("toolbar-style"));
 
-	createTrayIcon_gui();
+	createStatusIcon_gui();
 }
 
 MainWindow::~MainWindow()
@@ -280,7 +275,7 @@ MainWindow::~MainWindow()
 	gtk_widget_destroy(getWidget("flistDialog"));
 	gtk_widget_destroy(getWidget("aboutDialog"));
 	gtk_widget_destroy(GTK_WIDGET(window));
-	gtk_widget_destroy(trayIcon);
+	g_object_unref(statusIcon);
 
 	// Make sure the pixmaps are freed (using gtk's ref counting).
 	g_object_unref(G_OBJECT(uploadPic));
@@ -311,6 +306,18 @@ void MainWindow::show()
 	autoOpen_gui();
 }
 
+void MainWindow::setTitle(const string& text)
+{
+	string title;
+
+	if (!text.empty())
+		title = text + " - " + g_get_application_name();
+	else
+		title = g_get_application_name();
+
+	gtk_window_set_title(window, title.c_str());
+}
+
 bool MainWindow::isActive_gui()
 {
 	return gtk_window_is_active(window);
@@ -354,9 +361,7 @@ void MainWindow::addBookEntry_gui(BookEntry *entry)
 
 	gtk_widget_set_sensitive(getWidget("closeMenuItem"), TRUE);
 
-#if GTK_CHECK_VERSION(2, 10, 0)
 	gtk_notebook_set_tab_reorderable(GTK_NOTEBOOK(getWidget("book")), page, TRUE);
-#endif
 
 	entry->show();
 }
@@ -408,7 +413,10 @@ void MainWindow::removeBookEntry_gui(BookEntry *entry)
 		removeTabMenuItem_gui(menuItem);
 
 		if (gtk_notebook_get_n_pages(book) == 0)
+		{
 			gtk_widget_set_sensitive(getWidget("closeMenuItem"), FALSE);
+			setTitle(""); // Reset window title to default
+		}
 	}
 }
 
@@ -458,33 +466,29 @@ void MainWindow::removeTabMenuItem_gui(GtkWidget *menuItem)
 }
 
 /*
- * Create tray icon.
- * @todo: Replace with GtkStatusIcon after GTK+ 2.10 is released and on enough systems.
+ * Create status icon.
  */
-void MainWindow::createTrayIcon_gui()
+void MainWindow::createStatusIcon_gui()
 {
 	string iconPath = WulforManager::get()->getPath() + "/pixmaps/linuxdcpp-icon.png";
-	trayToolTip = gtk_tooltips_new();
+	statusIcon = gtk_status_icon_new_from_file(iconPath.c_str());
 
-	trayIcon = GTK_WIDGET(egg_tray_icon_new("LinuxDC++"));
-	GtkWidget *trayBox = gtk_event_box_new();
-	GtkWidget *trayImage = gtk_image_new_from_file(iconPath.c_str());
-	gtk_container_add(GTK_CONTAINER(trayBox), trayImage);
-	gtk_container_add(GTK_CONTAINER(trayIcon), trayBox);
-
-	g_signal_connect(getWidget("quitTrayItem"), "activate", G_CALLBACK(onQuitClicked_gui), (gpointer)this);
-	g_signal_connect(getWidget("toggleInterfaceItem"), "activate", G_CALLBACK(onToggleWindowVisibility_gui), (gpointer)this);
-	g_signal_connect(trayIcon, "button-press-event", G_CALLBACK(onTrayIconClicked_gui), (gpointer)this);
+	g_signal_connect(getWidget("statusIconQuitItem"), "activate", G_CALLBACK(onQuitClicked_gui), (gpointer)this);
+	g_signal_connect(getWidget("statusIconToggleInterfaceItem"), "activate", G_CALLBACK(onToggleWindowVisibility_gui), (gpointer)this);
+	g_signal_connect(statusIcon, "activate", G_CALLBACK(onStatusIconActivated_gui), (gpointer)this);
+	g_signal_connect(statusIcon, "popup-menu", G_CALLBACK(onStatusIconPopupMenu_gui), (gpointer)this);
 
 	if (BOOLSETTING(MINIMIZE_TRAY))
-		gtk_widget_show_all(trayIcon);
+		gtk_status_icon_set_visible(statusIcon, TRUE);
+	else
+		gtk_status_icon_set_visible(statusIcon, FALSE);
 }
 
-void MainWindow::updateTrayToolTip_gui(string download, string upload)
+void MainWindow::updateStatusIconTooltip_gui(string download, string upload)
 {
 	ostringstream toolTip;
-	toolTip << "LinuxDC++" << endl << _("Download: ") << download << endl << _("Upload: ") << upload;
-	gtk_tooltips_set_tip(trayToolTip, trayIcon, toolTip.str().c_str(), NULL);
+	toolTip << g_get_application_name() << endl << _("Download: ") << download << endl << _("Upload: ") << upload;
+	gtk_status_icon_set_tooltip(statusIcon, toolTip.str().c_str());
 }
 
 void MainWindow::setMainStatus_gui(string text, time_t t)
@@ -694,7 +698,7 @@ void MainWindow::updateTransfer_gui(StringMap params, bool download)
 
 	for (StringMap::const_iterator it = params.begin(); it != params.end(); ++it)
 	{
-		if (it->first == "Size Order" || it->first == "Speed Order")
+		if (it->first == "Size" || it->first == "Speed")
 			gtk_list_store_set(transferStore, &iter, transferView.col(it->first), Util::toInt64(it->second), -1);
 		else if (it->first == "Progress")
 			gtk_list_store_set(transferStore, &iter, transferView.col(it->first), Util::toInt(it->second), -1);
@@ -862,6 +866,21 @@ void MainWindow::openMagnetDialog_gui(const string &magnet)
 	gtk_widget_hide(getWidget("magnetDialog"));
 }
 
+void MainWindow::showMessageDialog_gui(const string primaryText, const string secondaryText)
+{
+	if (primaryText.empty())
+		return;
+
+	GtkWidget* dialog = gtk_message_dialog_new(window, GTK_DIALOG_DESTROY_WITH_PARENT, 
+		GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, "%s", primaryText.c_str());
+
+	if (!secondaryText.empty())
+		gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog), "%s", secondaryText.c_str());
+
+	gtk_dialog_run(GTK_DIALOG(dialog));
+	gtk_widget_destroy(dialog);
+}
+
 gboolean MainWindow::onWindowState_gui(GtkWidget *widget, GdkEventWindowState *event, gpointer data)
 {
 	MainWindow *mw = (MainWindow *)data;
@@ -996,11 +1015,16 @@ void MainWindow::onRaisePage_gui(GtkMenuItem *item, gpointer data)
 
 void MainWindow::onPageSwitched_gui(GtkNotebook *notebook, GtkNotebookPage *page, guint num, gpointer data)
 {
+	MainWindow* mw = (MainWindow*)data;
 	GtkWidget *child = gtk_notebook_get_nth_page(notebook, num);
 	BookEntry *entry = (BookEntry *)g_object_get_data(G_OBJECT(child), "entry");
 
 	if (entry)
+	{
 		entry->setActive_gui();
+		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(entry->getTabMenuItem()), TRUE);
+		mw->setTitle(entry->getLabelText()); // Update window title with selected tab label
+	}
 
 	GList *list = (GList *)g_object_get_data(G_OBJECT(notebook), "page-rotation-list");
 	list = g_list_remove(list, (gpointer)child);
@@ -1092,9 +1116,9 @@ void MainWindow::onPreferencesClicked_gui(GtkWidget *widget, gpointer data)
 		}
 
 		if (BOOLSETTING(MINIMIZE_TRAY))
-			gtk_widget_show_all(mw->trayIcon);
+			gtk_status_icon_set_visible(mw->statusIcon, TRUE);
 		else
-			gtk_widget_hide_all(mw->trayIcon);
+			gtk_status_icon_set_visible(mw->statusIcon, FALSE);
 
 		mw->setTabPosition_gui(WGETI("tab-position"));
 		mw->setToolbarStyle_gui(WGETI("toolbar-style"));
@@ -1166,8 +1190,8 @@ void MainWindow::onOpenFileListClicked_gui(GtkWidget *widget, gpointer data)
 void MainWindow::onOpenOwnListClicked_gui(GtkWidget *widget, gpointer data)
 {
 	MainWindow *mw = (MainWindow *)data;
-	typedef Func0<MainWindow> F0;
-	F0 *func = new F0(mw, &MainWindow::openOwnList_client);
+	typedef Func1<MainWindow, bool> F1;
+	F1 *func = new F1(mw, &MainWindow::openOwnList_client, FALSE);
 	WulforManager::get()->dispatchClientFunc(func);
 
 	mw->setMainStatus_gui(_("Loading file list"));
@@ -1440,14 +1464,16 @@ void MainWindow::onCloseConnectionClicked_gui(GtkMenuItem *menuItem, gpointer da
 	g_list_free(list);
 }
 
-void MainWindow::onTrayIconClicked_gui(GtkWidget *widget, GdkEventButton *event, gpointer data)
+void MainWindow::onStatusIconActivated_gui(GtkStatusIcon *statusIcon, gpointer data)
+{
+	onToggleWindowVisibility_gui(NULL, data);
+}
+
+void MainWindow::onStatusIconPopupMenu_gui(GtkStatusIcon *statusIcon, guint button, guint time, gpointer data)
 {
 	MainWindow *mw = (MainWindow *)data;
-
-	if (event->type == GDK_BUTTON_PRESS && event->button == 1)
-		onToggleWindowVisibility_gui(NULL, data);
-	else if (event->type == GDK_BUTTON_PRESS && event->button == 3)
-		gtk_menu_popup(GTK_MENU(mw->getWidget("trayMenu")), NULL, NULL, NULL, NULL, 0, gtk_get_current_event_time());
+	GtkMenu *menu = GTK_MENU(mw->getWidget("statusIconMenu"));
+	gtk_menu_popup(menu, NULL, NULL, gtk_status_icon_position_menu, statusIcon, button, time);
 }
 
 void MainWindow::onToggleWindowVisibility_gui(GtkMenuItem *item, gpointer data)
@@ -1507,7 +1533,12 @@ void MainWindow::startSocket_client()
 		}
 		catch (const Exception &e)
 		{
-			cerr << "StartSocket (tcp): Caught \"" << e.getError() << "\"" << endl;
+			string primaryText = _("Unable to open TCP/TLS port");
+			string secondaryText = _("File transfers will not work correctly until you change settings or turn off any application that might be using the TCP/TLS port.");
+			typedef Func2<MainWindow, string, string> F2;
+			F2* func = new F2(this, &MainWindow::showMessageDialog_gui, primaryText, secondaryText);
+			WulforManager::get()->dispatchGuiFunc(func);
+
 		}
 
 		try
@@ -1516,7 +1547,11 @@ void MainWindow::startSocket_client()
 		}
 		catch (const Exception &e)
 		{
-			cerr << "StartSocket (udp): Caught \"" << e.getError() << "\"" << endl;
+			string primaryText = _("Unable to open UDP port");
+			string secondaryText = _("Searching will not work correctly until you change settings or turn off any application that might be using the UDP port.");
+			typedef Func2<MainWindow, string, string> F2;
+			F2* func = new F2(this, &MainWindow::showMessageDialog_gui, primaryText, secondaryText);
+			WulforManager::get()->dispatchGuiFunc(func);
 		}
 	}
 
@@ -1535,13 +1570,13 @@ void MainWindow::refreshFileList_client()
 	}
 }
 
-void MainWindow::openOwnList_client()
+void MainWindow::openOwnList_client(bool useSetting)
 {
 	User::Ptr user = ClientManager::getInstance()->getMe();
 	string path = ShareManager::getInstance()->getOwnListFile();
 
 	typedef Func4<MainWindow, User::Ptr, string, string, bool> F4;
-	F4 *func = new F4(this, &MainWindow::showShareBrowser_gui, user, path, "", FALSE);
+	F4 *func = new F4(this, &MainWindow::showShareBrowser_gui, user, path, "", useSetting);
 	WulforManager::get()->dispatchGuiFunc(func);
 }
 
@@ -1629,8 +1664,7 @@ void MainWindow::transferComplete_client(Transfer *t)
 	params["CID"] = user->getCID().toBase32();
 	params["Progress"] = "100";
 	params["Time Left"] = _("Done");
-	params["Speed"] = " ";
-	params["Speed Order"] = "0";
+	params["Speed"] = "-1";		// Setting speed < 0 clears the TreeView::SPEED column.
 	params["Sort Order"] = "w" + WulforUtil::getNicks(user) + WulforUtil::getHubNames(user);
 
 	if (t->getUserConnection().isSet(UserConnection::FLAG_DOWNLOAD))
@@ -1659,8 +1693,7 @@ void MainWindow::on(ConnectionManagerListener::Added, ConnectionQueueItem *cqi)
 	params["Status"] = _("Connecting...");
 	params["Progress"] = "0";
 	params["Time Left"] = " ";
-	params["Speed"] = " ";
-	params["Speed Order"] = "0";
+	params["Speed"] = "-1";
 	params["Sort Order"] = "w" + params["User"] + params["Hub Name"];
 
 	typedef Func2<MainWindow, StringMap, bool> F2;
@@ -1685,8 +1718,7 @@ void MainWindow::on(ConnectionManagerListener::Failed, ConnectionQueueItem *cqi,
 	params["CID"] = user->getCID().toBase32();
 	params["Status"] = reason;
 	params["Time Left"] = " ";
-	params["Speed"] = " ";
-	params["Speed Order"] = "0";
+	params["Speed"] = "-1";
 	params["Sort Order"] = "w" + WulforUtil::getNicks(user) + WulforUtil::getHubNames(user);
 
 	typedef Func2<MainWindow, StringMap, bool> F2;
@@ -1700,8 +1732,7 @@ void MainWindow::on(ConnectionManagerListener::StatusChanged, ConnectionQueueIte
 
 	params["CID"] = cqi->getUser()->getCID().toBase32();
 	params["Time Left"] = " ";
-	params["Speed"] = " ";
-	params["Speed Order"] = "0";
+	params["Speed"] = "-1";
 
 	if (cqi->getState() == ConnectionQueueItem::CONNECTING)
 		params["Status"] = _("Connecting...");
@@ -1728,8 +1759,7 @@ void MainWindow::on(DownloadManagerListener::Starting, Download *dl) throw()
 	params["CID"] = user->getCID().toBase32();
 	params["Path"] = Util::getFilePath(dl->getTarget());
 	params["Status"] = _("Download starting...");
-	params["Size"] = Util::formatBytes(dl->getSize());
-	params["Size Order"] = Util::toString(dl->getSize());
+	params["Size"] = Util::toString(dl->getSize());
 	params["Sort Order"] = "d" + WulforUtil::getNicks(user) + WulforUtil::getHubNames(user);
 	params["IP"] = dl->getUserConnection().getRemoteIp();
 
@@ -1782,8 +1812,7 @@ void MainWindow::on(DownloadManagerListener::Tick, const Download::List &list) t
 		params["Status"] = status + stream.str();
 		params["Time Left"] = Util::formatSeconds(dl->getSecondsLeft());
 		params["Progress"] = Util::toString((int)percent);
-		params["Speed"] = Util::formatBytes(dl->getRunningAverage()).append("/s");
-		params["Speed Order"] = Util::toString(dl->getRunningAverage());
+		params["Speed"] = Util::toString(dl->getRunningAverage());
 
 		func = new F2(this, &MainWindow::updateTransfer_gui, params, TRUE);
 		WulforManager::get()->dispatchGuiFunc(func);
@@ -1811,10 +1840,8 @@ void MainWindow::on(DownloadManagerListener::Failed, Download *dl, const string
 	params["Path"] = Util::getFilePath(dl->getTarget());
 	params["Status"] = reason;
 	params["Time Left"] = " ";
-	params["Speed"] = " ";
-	params["Speed Order"] = "0";
-	params["Size"] = Util::formatBytes(dl->getSize());
-	params["Size Order"] = Util::toString(dl->getSize());
+	params["Speed"] = "-1";
+	params["Size"] = Util::toString(dl->getSize());
 	params["Sort Order"] = "w" + WulforUtil::getNicks(user) + WulforUtil::getHubNames(user);
 
 	typedef Func2<MainWindow, StringMap, bool> F2;
@@ -1837,8 +1864,7 @@ void MainWindow::on(UploadManagerListener::Starting, Upload *ul) throw()
 	params["CID"] = user->getCID().toBase32();
 	params["Path"] = Util::getFilePath(ul->getSourceFile());
 	params["Status"] = _("Upload starting...");
-	params["Size"] = Util::formatBytes(ul->getSize());
-	params["Size Order"] = Util::toString(ul->getSize());
+	params["Size"] = Util::toString(ul->getSize());
 	params["Sort Order"] = "u" + WulforUtil::getNicks(user) + WulforUtil::getHubNames(user);
 	params["IP"] = ul->getUserConnection().getRemoteIp();
 
@@ -1887,8 +1913,7 @@ void MainWindow::on(UploadManagerListener::Tick, const Upload::List &list) throw
 		params["Status"] = status + stream.str();
 		params["Time Left"] = Util::formatSeconds(ul->getSecondsLeft());
 		params["Progress"] = Util::toString((int)percent);
-		params["Speed"] = Util::formatBytes(ul->getRunningAverage()).append("/s");
-		params["Speed Order"] = Util::toString(ul->getRunningAverage());
+		params["Speed"] = Util::toString(ul->getRunningAverage());
 
 		func = new F2(this, &MainWindow::updateTransfer_gui, params, FALSE);
 		WulforManager::get()->dispatchGuiFunc(func);
@@ -1956,7 +1981,7 @@ void MainWindow::on(TimerManagerListener::Second, uint32_t ticks) throw()
 	if (BOOLSETTING(MINIMIZE_TRAY) && !status5.empty() && !status6.empty())
 	{
 		typedef Func2<MainWindow, string, string> F2;
-		F2 *f2 = new F2(this, &MainWindow::updateTrayToolTip_gui, status5, status6);
+		F2 *f2 = new F2(this, &MainWindow::updateStatusIconTooltip_gui, status5, status6);
 		WulforManager::get()->dispatchGuiFunc(f2);
 	}
 }
