@@ -573,7 +573,7 @@ void Settings::initAppearance_gui()
 		g_list_free(list);
 
 		addOption_gui(appearanceStore, _("Filter kick and NMDC debug messages"), SettingsManager::FILTER_MESSAGES);
-		addOption_gui(appearanceStore, _("Show tray icon"), SettingsManager::MINIMIZE_TRAY);
+		addOption_gui(appearanceStore, _("Show status icon"), SettingsManager::MINIMIZE_TRAY);
 		addOption_gui(appearanceStore, _("Show timestamps in chat by default"), SettingsManager::TIME_STAMPS);
 		addOption_gui(appearanceStore, _("View status messages in main chat"), SettingsManager::STATUS_IN_CHAT);
 		addOption_gui(appearanceStore, _("Show joins / parts in chat by default"), SettingsManager::SHOW_JOINS);
@@ -1023,7 +1023,7 @@ bool Settings::validateUserCommandInput(const string &oldName)
 void Settings::showErrorDialog(const std::string &error)
 {
 	GtkWidget *errorDialog = gtk_message_dialog_new(GTK_WINDOW(getWidget("dialog")),
-		GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, error.c_str());
+		GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", error.c_str());
 	gtk_dialog_run(GTK_DIALOG(errorDialog));
 	gtk_widget_destroy(errorDialog);
 }
