@@ -92,9 +92,7 @@ ShareBrowser::ShareBrowser(User::Ptr user, const std::string &file, const std::s
 	gtk_tree_view_set_model(dirView.get(), GTK_TREE_MODEL(dirStore));
 	g_object_unref(dirStore);
 	dirSelection = gtk_tree_view_get_selection(dirView.get());
-#if GTK_CHECK_VERSION(2, 10, 0)
 	gtk_tree_view_set_enable_tree_lines(dirView.get(), TRUE);
-#endif
 
 	// Initialize the user command menus
 	fileUserCommandMenu = new UserCommandMenu(getWidget("fileUserCommandMenu"), ::UserCommand::CONTEXT_FILELIST);
